#include "svg.h"
#include <iostream>
#include <vector>
#include <cmath>

using namespace std;

void
svg_begin(double width, double height) {
    cout << "<?xml version='1.0' encoding='UTF-8'?>\n";
    cout << "<svg ";
    cout << "width='" << width << "' ";
    cout << "height='" << height << "' ";
    cout << "viewBox='0 0 " << width << " " << height << "' ";
    cout << "xmlns='http://www.w3.org/2000/svg'>\n";
}

void
svg_end() {
    cout << "</svg>\n";
}

void
svg_text(double left, double baseline, string text) {
    cout << "<text x='" << left << "' y='" << baseline << "'>" << text << "</text>";
}

void svg_rect(double x, double y, double width, double height, string stroke = "black", string fill = "black"){
    cout << "<rect x='" << x << "' y='" << y << "' width='" << width << "' height='" << height << "' stroke='" << stroke << "' fill='#" << fill << fill << fill << "' />";
}

void color_find(double bin, int maxb, int& color){
    color = (10 - (bin * 9) / maxb);
    if (color < 0) { cout << "cant take color";
    color = 9;
    }
}

void
show_histogram_svg(const vector<double>& bins) {

    const auto IMAGE_WIDTH = 400;
    const auto IMAGE_HEIGHT = 300;
    const auto TEXT_LEFT = 20;
    const auto TEXT_BASELINE = 20;
    const auto TEXT_WIDTH = 50;
    const auto BIN_HEIGHT = 30;
    const auto BLOCK_WIDTH = 10;

    svg_begin(400, 300);

    double top = 0;
    const size_t MAX_ASTERISK = IMAGE_WIDTH - TEXT_WIDTH;
    int maxb = bins[0];
    int color;

    for (size_t j = 1; j < bins.size(); j++)
    {
        if (bins[j] > maxb) maxb = bins[j];
    }

    int maxb1 = maxb * BLOCK_WIDTH;

    for (size_t bin : bins) {

    double bin_width;

    color_find(bin, maxb, color);

        if (maxb1 > MAX_ASTERISK)
        {
            bin_width  = BLOCK_WIDTH * MAX_ASTERISK * (bin / maxb1);
        }
        else bin_width = BLOCK_WIDTH * bin;

    svg_text(TEXT_LEFT, top + TEXT_BASELINE, to_string(bin));
    svg_rect(TEXT_WIDTH, top, bin_width, BIN_HEIGHT, "violet", to_string(color));
    top += BIN_HEIGHT;
}

    svg_end();
}
